SideBar class

Inheritance

Constructors

SideBar({Key? key, required List<AdminMenuItem> items, required String selectedRoute, void onSelected(AdminMenuItem item)?, double width = 240.0, Color? iconColor, Color? activeIconColor, TextStyle textStyle = const TextStyle(color: Color(0xFF337ab7), fontSize: 12), TextStyle activeTextStyle = const TextStyle(color: Color(0xFF337ab7), fontSize: 12), Color backgroundColor = const Color(0xFFEEEEEE), Color activeBackgroundColor = const Color(0xFFE7E7E7), Color borderColor = const Color(0xFFE7E7E7), ScrollController? scrollController, Widget? header, Widget? footer})
const

Properties

activeBackgroundColor → Color
final
activeIconColor → Color?
final
activeTextStyle → TextStyle
final
backgroundColor → Color
final
borderColor → Color
final
final
hashCode → int
The hash code for this object.
no setterinherited
final
iconColor → Color?
final
items → List<AdminMenuItem>
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onSelected → void Function(AdminMenuItem item)?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollController → ScrollController?
final
selectedRoute → String
final
textStyle → TextStyle
final
width → double
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _SideBarState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited